function [residual, g1, g2, g3] = covidmacro_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 56, 1);

%
% Model equations
%

T91 = (1-y(50))^params(26)*params(3);
T242 = y(23)^(-params(10));
T292 = y(27)^(-params(10));
T319 = y(30)/params(16)*y(41);
T320 = y(17)^(-params(10));
T325 = (y(8)+y(1)+y(7))*T320+y(2)*T242+y(3)*T292;
T328 = y(31)^params(17);
T337 = y(31)^(params(17)-1);
T372 = (y(31)/(y(31)))^params(20);
T378 = (y(41))/(y(6))+x(8);
T379 = y(41)/y(6)/T378;
T381 = T379^params(21);
T382 = T372*T381;
T385 = exp(y(2))^params(22);
lhs =y(11);
rhs =min(3*params(4),params(4)*(1+y(2)/params(6)));
residual(1)= lhs-rhs;
lhs =y(12);
rhs =0.3888888888888889-y(11);
residual(2)= lhs-rhs;
lhs =y(5);
rhs =y(1)*y(20);
residual(3)= lhs-rhs;
lhs =y(1);
rhs =y(1)-y(5);
residual(4)= lhs-rhs;
lhs =y(2);
rhs =y(2)+y(5)*params(8)-y(2)*(y(11)+y(12));
residual(5)= lhs-rhs;
lhs =y(7);
rhs =y(7)+y(5)*(1-params(8))-(y(11)+y(12))*y(7);
residual(6)= lhs-rhs;
lhs =y(3);
rhs =y(3)+y(2)*y(12)+params(9)*y(8);
residual(7)= lhs-rhs;
lhs =y(8);
rhs =(y(11)+y(12))*y(7)+y(8)*(1-params(9));
residual(8)= lhs-rhs;
lhs =y(4);
rhs =y(4)+y(11)*y(2);
residual(9)= lhs-rhs;
lhs =y(6);
rhs =y(6)-y(11)*y(2);
residual(10)= lhs-rhs;
lhs =y(20);
rhs =params(1)*y(17)*(y(2)*params(13)*y(23)+y(17)*y(7)*params(7))+params(2)*y(18)*(y(2)*params(15)*y(24)+y(7)*params(7)*y(18))+T91*(y(2)+y(7)*params(7));
residual(11)= lhs-rhs;
lhs =y(10);
rhs =((1-params(9))*y(10)+(y(11)+y(12))*y(9))/(1-y(20));
residual(12)= lhs-rhs;
lhs =y(9);
rhs =y(9)*(1-y(12)-y(11))/(1-y(20))+y(20)*(1-params(8))/(1-y(20));
residual(13)= lhs-rhs;
lhs =y(13);
rhs =1-y(14)-y(15);
residual(14)= lhs-rhs;
lhs =y(14);
rhs =y(20)*params(8)/(y(10)+1+y(9));
residual(15)= lhs-rhs;
lhs =y(15);
rhs =params(9)*y(10)/(y(10)+1+y(9));
residual(16)= lhs-rhs;
lhs =y(16);
rhs =log(y(17))+params(11)*log(1-y(18))+params(12)*((1-y(14)-y(15))*y(16)+y(14)*y(22)+y(15)*y(26));
residual(17)= lhs-rhs;
lhs =(y(8)+y(1)+y(7))*(y(17)+y(37)-y(18)*y(30)-y(36));
rhs =y(37)*(y(45)-params(8)*(y(45)-y(1))+y(48)+(1-params(9))*y(49))*y(40)/y(31);
residual(18)= lhs-rhs;
lhs =y(17)^(-1);
rhs =(1+y(50))*y(19)-(y(2)*params(13)*y(23)+y(17)*y(7)*params(7))*params(1)*y(21);
residual(19)= lhs-rhs;
lhs =params(8)*params(12)*(y(22)-y(16));
rhs =(y(10)+1+y(9))*y(21);
residual(20)= lhs-rhs;
lhs =params(11)/(1-y(18));
rhs =y(19)*y(30)*(1-y(53))+(y(2)*params(15)*y(24)+y(7)*params(7)*y(18))*params(2)*y(21);
residual(21)= lhs-rhs;
lhs =y(19);
rhs =y(40)*y(19)*(1-y(14)-y(15))*params(12)/y(31)+y(40)*y(14)*params(12)*y(25)/y(31)+y(40)*y(15)*params(12)*y(29)/y(31);
residual(22)= lhs-rhs;
lhs =y(22);
rhs =log(y(23))+params(11)*log(1-y(24))+params(12)*((1-y(12)-y(11))*y(22)+y(12)*y(26)+y(11)*params(19));
residual(23)= lhs-rhs;
lhs =y(2)*(y(23)+y(39)-y(24)*y(30)*params(14)-y(36));
rhs =y(40)*((1-y(12))*y(39)*y(46)+(y(45)-y(1))*params(8)*y(37))/y(31);
residual(24)= lhs-rhs;
lhs =T242;
rhs =y(25)*(1+y(51));
residual(25)= lhs-rhs;
lhs =y(24);
rhs =max(1-params(11)/(y(25)*y(30)*params(14)),0);
residual(26)= lhs-rhs;
lhs =y(25);
rhs =y(40)*y(25)*(1-y(12)-y(11))*params(12)/y(31)/(1-y(11))+y(40)*y(29)*y(12)*params(12)/y(31)/(1-y(11));
residual(27)= lhs-rhs;
lhs =y(26);
rhs =log(y(27))+params(11)*log(1-y(28))+params(12)*y(26);
residual(28)= lhs-rhs;
lhs =y(3)*(y(27)+y(38)-y(30)*y(28)-y(36));
rhs =y(40)*(y(38)*y(47)+y(46)*y(12)*y(39)+y(49)*params(9)*y(37))/y(31);
residual(29)= lhs-rhs;
lhs =T292;
rhs =y(29)*(1+y(52));
residual(30)= lhs-rhs;
lhs =params(11)/(1-y(28));
rhs =y(29)*y(30)*(1-y(55));
residual(31)= lhs-rhs;
lhs =y(29);
rhs =y(40)*params(12)*y(29)/y(31);
residual(32)= lhs-rhs;
lhs =y(32);
rhs =y(33)/y(34);
residual(33)= lhs-rhs;
lhs =y(33)/(1-params(12)*params(18));
rhs =T319*T325+y(33)*params(12)*params(18)*T328/(1-params(12)*params(18));
residual(34)= lhs-rhs;
lhs =y(34)/(1-params(12)*params(18));
rhs =y(41)*T325+y(34)*params(12)*params(18)*T337/(1-params(12)*params(18));
residual(35)= lhs-rhs;
lhs =1;
rhs =params(18)*T337+(1-params(18))*y(32)^(1-params(17));
residual(36)= lhs-rhs;
lhs =y(35);
rhs =y(35)*params(18)*T328+(1-params(18))*y(32)^(-params(17));
residual(37)= lhs-rhs;
lhs =y(41)-y(30)*y(43);
rhs =y(36)*(y(8)+y(7)+y(3)+y(2)+y(1));
residual(38)= lhs-rhs;
lhs =y(40)/(y(40));
rhs =T382*T385*exp(x(7));
residual(39)= lhs-rhs;
residual(40) = (y(8)+y(1)+y(7))*y(37)+y(3)*y(38)+y(2)*y(39);
lhs =y(42);
rhs =y(17)*(y(8)+y(1)+y(7))+y(2)*y(23)+y(3)*y(27);
residual(41)= lhs-rhs;
lhs =y(43);
rhs =y(18)*(y(8)+y(1)+y(7))+params(14)*y(2)*y(24)+y(3)*y(28);
residual(42)= lhs-rhs;
lhs =y(41)*y(35);
rhs =params(16)*y(43);
residual(43)= lhs-rhs;
lhs =y(44);
rhs =y(41)-y(42);
residual(44)= lhs-rhs;
lhs =y(45);
rhs =y(1);
residual(45)= lhs-rhs;
lhs =y(46);
rhs =y(2);
residual(46)= lhs-rhs;
lhs =y(47);
rhs =y(3);
residual(47)= lhs-rhs;
lhs =y(48);
rhs =y(7);
residual(48)= lhs-rhs;
lhs =y(49);
rhs =y(8);
residual(49)= lhs-rhs;
lhs =y(50);
rhs =y(50)*params(27)+x(1);
residual(50)= lhs-rhs;
lhs =y(51);
rhs =y(51)*params(28)+x(2);
residual(51)= lhs-rhs;
lhs =y(52);
rhs =y(52)*params(29)+x(3);
residual(52)= lhs-rhs;
lhs =y(53);
rhs =y(53)*params(30)+x(4);
residual(53)= lhs-rhs;
lhs =y(54);
rhs =y(54)*params(31)+x(5);
residual(54)= lhs-rhs;
lhs =y(55);
rhs =y(55)*params(32)+x(6);
residual(55)= lhs-rhs;
lhs =y(56);
rhs =(log(y(17))+params(11)*log(1-y(18)))*(y(8)+y(1)+y(7))+y(2)*(log(y(23))+params(11)*log(1-y(24)))+y(3)*(log(y(27))+params(11)*log(1-y(28)))-y(4)*(log(y(27))-params(11)*log(1-y(28)));
residual(56)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(56, 56);

  %
  % Jacobian matrix
  %

T535 = getPowerDeriv(T379,params(21),1);
T642 = (y(8)+y(1)+y(7))*getPowerDeriv(y(17),(-params(10)),1);
T697 = getPowerDeriv(y(23),(-params(10)),1);
T740 = getPowerDeriv(y(27),(-params(10)),1);
T822 = getPowerDeriv(y(31),params(17),1);
T827 = getPowerDeriv(y(31),params(17)-1,1);
  g1(1,2)=(-(params(4)*1/params(6)*(1-(params(4)*(1+y(2)/params(6))>3*params(4)))));
  g1(1,11)=1;
  g1(2,11)=1;
  g1(2,12)=1;
  g1(3,1)=(-y(20));
  g1(3,5)=1;
  g1(3,20)=(-y(1));
  g1(4,5)=1;
  g1(5,2)=1-(1-(y(11)+y(12)));
  g1(5,5)=(-params(8));
  g1(5,11)=y(2);
  g1(5,12)=y(2);
  g1(6,5)=(-(1-params(8)));
  g1(6,7)=1-(1-(y(11)+y(12)));
  g1(6,11)=y(7);
  g1(6,12)=y(7);
  g1(7,2)=(-y(12));
  g1(7,8)=(-params(9));
  g1(7,12)=(-y(2));
  g1(8,7)=(-(y(11)+y(12)));
  g1(8,8)=1-(1-params(9));
  g1(8,11)=(-y(7));
  g1(8,12)=(-y(7));
  g1(9,2)=(-y(11));
  g1(9,11)=(-y(2));
  g1(10,2)=y(11);
  g1(10,11)=y(2);
  g1(11,2)=(-(T91+params(1)*y(17)*params(13)*y(23)+params(2)*y(18)*params(15)*y(24)));
  g1(11,7)=(-(params(1)*y(17)*y(17)*params(7)+params(2)*y(18)*params(7)*y(18)+params(7)*T91));
  g1(11,17)=(-(params(1)*(y(2)*params(13)*y(23)+y(17)*y(7)*params(7))+params(1)*y(17)*y(7)*params(7)));
  g1(11,18)=(-(params(2)*(y(2)*params(15)*y(24)+y(7)*params(7)*y(18))+y(7)*params(7)*params(2)*y(18)));
  g1(11,20)=1;
  g1(11,23)=(-(params(1)*y(17)*y(2)*params(13)));
  g1(11,24)=(-(params(2)*y(18)*y(2)*params(15)));
  g1(11,50)=(-((y(2)+y(7)*params(7))*params(3)*(-(getPowerDeriv(1-y(50),params(26),1)))));
  g1(12,9)=(-((y(11)+y(12))/(1-y(20))));
  g1(12,10)=1-(1-params(9))/(1-y(20));
  g1(12,11)=(-(y(9)/(1-y(20))));
  g1(12,12)=(-(y(9)/(1-y(20))));
  g1(12,20)=(-(((1-params(9))*y(10)+(y(11)+y(12))*y(9))/((1-y(20))*(1-y(20)))));
  g1(13,9)=1-(1-y(12)-y(11))/(1-y(20));
  g1(13,11)=(-((-y(9))/(1-y(20))));
  g1(13,12)=(-((-y(9))/(1-y(20))));
  g1(13,20)=(-(y(9)*(1-y(12)-y(11))/((1-y(20))*(1-y(20)))+((1-params(8))*(1-y(20))-(-(y(20)*(1-params(8)))))/((1-y(20))*(1-y(20)))));
  g1(14,13)=1;
  g1(14,14)=1;
  g1(14,15)=1;
  g1(15,9)=(-((-(y(20)*params(8)))/((y(10)+1+y(9))*(y(10)+1+y(9)))));
  g1(15,10)=(-((-(y(20)*params(8)))/((y(10)+1+y(9))*(y(10)+1+y(9)))));
  g1(15,14)=1;
  g1(15,20)=(-(params(8)/(y(10)+1+y(9))));
  g1(16,9)=(-((-(params(9)*y(10)))/((y(10)+1+y(9))*(y(10)+1+y(9)))));
  g1(16,10)=(-((params(9)*(y(10)+1+y(9))-params(9)*y(10))/((y(10)+1+y(9))*(y(10)+1+y(9)))));
  g1(16,15)=1;
  g1(17,14)=(-(params(12)*(y(22)+(-y(16)))));
  g1(17,15)=(-(params(12)*(y(26)+(-y(16)))));
  g1(17,16)=1-(1-y(14)-y(15))*params(12);
  g1(17,17)=(-(1/y(17)));
  g1(17,18)=(-(params(11)*(-1)/(1-y(18))));
  g1(17,22)=(-(y(14)*params(12)));
  g1(17,26)=(-(y(15)*params(12)));
  g1(18,1)=y(17)+y(37)-y(18)*y(30)-y(36)-y(40)*params(8)*y(37)/y(31);
  g1(18,7)=y(17)+y(37)-y(18)*y(30)-y(36);
  g1(18,8)=y(17)+y(37)-y(18)*y(30)-y(36);
  g1(18,17)=y(8)+y(1)+y(7);
  g1(18,18)=(y(8)+y(1)+y(7))*(-y(30));
  g1(18,30)=(y(8)+y(1)+y(7))*(-y(18));
  g1(18,31)=(-((-(y(37)*(y(45)-params(8)*(y(45)-y(1))+y(48)+(1-params(9))*y(49))*y(40)))/(y(31)*y(31))));
  g1(18,36)=(-(y(8)+y(1)+y(7)));
  g1(18,37)=y(8)+y(1)+y(7)-(y(45)-params(8)*(y(45)-y(1))+y(48)+(1-params(9))*y(49))*y(40)/y(31);
  g1(18,40)=(-(y(37)*(y(45)-params(8)*(y(45)-y(1))+y(48)+(1-params(9))*y(49))/y(31)));
  g1(18,45)=(-(y(40)*(1-params(8))*y(37)/y(31)));
  g1(18,48)=(-(y(37)*y(40)/y(31)));
  g1(18,49)=(-(y(40)*(1-params(9))*y(37)/y(31)));
  g1(19,2)=params(1)*y(21)*params(13)*y(23);
  g1(19,7)=params(1)*y(21)*y(17)*params(7);
  g1(19,17)=getPowerDeriv(y(17),(-1),1)-(-(y(7)*params(7)*params(1)*y(21)));
  g1(19,19)=(-(1+y(50)));
  g1(19,21)=params(1)*(y(2)*params(13)*y(23)+y(17)*y(7)*params(7));
  g1(19,23)=y(2)*params(13)*params(1)*y(21);
  g1(19,50)=(-y(19));
  g1(20,9)=(-y(21));
  g1(20,10)=(-y(21));
  g1(20,16)=(-(params(8)*params(12)));
  g1(20,21)=(-(y(10)+1+y(9)));
  g1(20,22)=params(8)*params(12);
  g1(21,2)=(-(params(2)*y(21)*params(15)*y(24)));
  g1(21,7)=(-(params(2)*y(21)*params(7)*y(18)));
  g1(21,18)=params(11)/((1-y(18))*(1-y(18)))-y(7)*params(7)*params(2)*y(21);
  g1(21,19)=(-(y(30)*(1-y(53))));
  g1(21,21)=(-(params(2)*(y(2)*params(15)*y(24)+y(7)*params(7)*y(18))));
  g1(21,24)=(-(y(2)*params(15)*params(2)*y(21)));
  g1(21,30)=(-(y(19)*(1-y(53))));
  g1(21,53)=(-(y(19)*(-y(30))));
  g1(22,14)=(-(y(40)*y(19)*(-params(12))/y(31)+y(40)*params(12)*y(25)/y(31)));
  g1(22,15)=(-(y(40)*params(12)*y(29)/y(31)+y(40)*y(19)*(-params(12))/y(31)));
  g1(22,19)=1-y(40)*(1-y(14)-y(15))*params(12)/y(31);
  g1(22,25)=(-(y(40)*y(14)*params(12)/y(31)));
  g1(22,29)=(-(y(40)*y(15)*params(12)/y(31)));
  g1(22,31)=(-((-(y(40)*y(19)*(1-y(14)-y(15))*params(12)))/(y(31)*y(31))+(-(y(40)*y(14)*params(12)*y(25)))/(y(31)*y(31))+(-(y(40)*y(15)*params(12)*y(29)))/(y(31)*y(31))));
  g1(22,40)=(-(y(19)*(1-y(14)-y(15))*params(12)/y(31)+y(14)*params(12)*y(25)/y(31)+y(15)*params(12)*y(29)/y(31)));
  g1(23,11)=(-(params(12)*(params(19)+(-y(22)))));
  g1(23,12)=(-(params(12)*(y(26)+(-y(22)))));
  g1(23,22)=1-(1-y(12)-y(11))*params(12);
  g1(23,23)=(-(1/y(23)));
  g1(23,24)=(-(params(11)*(-1)/(1-y(24))));
  g1(23,26)=(-(y(12)*params(12)));
  g1(24,1)=(-(y(40)*(-(params(8)*y(37)))/y(31)));
  g1(24,2)=y(23)+y(39)-y(24)*y(30)*params(14)-y(36);
  g1(24,12)=(-(y(40)*(-(y(39)*y(46)))/y(31)));
  g1(24,23)=y(2);
  g1(24,24)=y(2)*(-(y(30)*params(14)));
  g1(24,30)=y(2)*(-(y(24)*params(14)));
  g1(24,31)=(-((-(y(40)*((1-y(12))*y(39)*y(46)+(y(45)-y(1))*params(8)*y(37))))/(y(31)*y(31))));
  g1(24,36)=(-y(2));
  g1(24,37)=(-(params(8)*(y(45)-y(1))*y(40)/y(31)));
  g1(24,39)=y(2)-y(40)*(1-y(12))*y(46)/y(31);
  g1(24,40)=(-(((1-y(12))*y(39)*y(46)+(y(45)-y(1))*params(8)*y(37))/y(31)));
  g1(24,45)=(-(y(40)*params(8)*y(37)/y(31)));
  g1(24,46)=(-(y(40)*(1-y(12))*y(39)/y(31)));
  g1(25,23)=T697;
  g1(25,25)=(-(1+y(51)));
  g1(25,51)=(-y(25));
  g1(26,24)=1;
  g1(26,25)=(-((-((-(params(11)*y(30)*params(14)))/(y(25)*y(30)*params(14)*y(25)*y(30)*params(14))))*(1-params(11)/(y(25)*y(30)*params(14))>0)));
  g1(26,30)=(-((1-params(11)/(y(25)*y(30)*params(14))>0)*(-((-(params(11)*y(25)*params(14)))/(y(25)*y(30)*params(14)*y(25)*y(30)*params(14))))));
  g1(27,11)=(-(((1-y(11))*y(40)*y(25)*(-params(12))/y(31)-(-(y(40)*y(25)*(1-y(12)-y(11))*params(12)/y(31))))/((1-y(11))*(1-y(11)))+y(40)*y(29)*y(12)*params(12)/y(31)/((1-y(11))*(1-y(11)))));
  g1(27,12)=(-(y(40)*y(25)*(-params(12))/y(31)/(1-y(11))+y(40)*params(12)*y(29)/y(31)/(1-y(11))));
  g1(27,25)=1-y(40)*(1-y(12)-y(11))*params(12)/y(31)/(1-y(11));
  g1(27,29)=(-(y(40)*y(12)*params(12)/y(31)/(1-y(11))));
  g1(27,31)=(-((-(y(40)*y(25)*(1-y(12)-y(11))*params(12)))/(y(31)*y(31))/(1-y(11))+(-(y(40)*y(29)*y(12)*params(12)))/(y(31)*y(31))/(1-y(11))));
  g1(27,40)=(-(y(25)*(1-y(12)-y(11))*params(12)/y(31)/(1-y(11))+y(29)*y(12)*params(12)/y(31)/(1-y(11))));
  g1(28,26)=1-params(12);
  g1(28,27)=(-(1/y(27)));
  g1(28,28)=(-(params(11)*(-1)/(1-y(28))));
  g1(29,3)=y(27)+y(38)-y(30)*y(28)-y(36);
  g1(29,12)=(-(y(40)*y(39)*y(46)/y(31)));
  g1(29,27)=y(3);
  g1(29,28)=y(3)*(-y(30));
  g1(29,30)=y(3)*(-y(28));
  g1(29,31)=(-((-(y(40)*(y(38)*y(47)+y(46)*y(12)*y(39)+y(49)*params(9)*y(37))))/(y(31)*y(31))));
  g1(29,36)=(-y(3));
  g1(29,37)=(-(y(40)*params(9)*y(49)/y(31)));
  g1(29,38)=y(3)-y(40)*y(47)/y(31);
  g1(29,39)=(-(y(40)*y(12)*y(46)/y(31)));
  g1(29,40)=(-((y(38)*y(47)+y(46)*y(12)*y(39)+y(49)*params(9)*y(37))/y(31)));
  g1(29,46)=(-(y(40)*y(12)*y(39)/y(31)));
  g1(29,47)=(-(y(40)*y(38)/y(31)));
  g1(29,49)=(-(y(40)*params(9)*y(37)/y(31)));
  g1(30,27)=T740;
  g1(30,29)=(-(1+y(52)));
  g1(30,52)=(-y(29));
  g1(31,28)=params(11)/((1-y(28))*(1-y(28)));
  g1(31,29)=(-(y(30)*(1-y(55))));
  g1(31,30)=(-(y(29)*(1-y(55))));
  g1(31,55)=(-(y(29)*(-y(30))));
  g1(32,29)=1-params(12)*y(40)/y(31);
  g1(32,31)=(-((-(y(40)*params(12)*y(29)))/(y(31)*y(31))));
  g1(32,40)=(-(params(12)*y(29)/y(31)));
  g1(33,32)=1;
  g1(33,33)=(-(1/y(34)));
  g1(33,34)=(-((-y(33))/(y(34)*y(34))));
  g1(34,1)=(-(T319*T320));
  g1(34,2)=(-(T242*T319));
  g1(34,3)=(-(T292*T319));
  g1(34,7)=(-(T319*T320));
  g1(34,8)=(-(T319*T320));
  g1(34,17)=(-(T319*T642));
  g1(34,23)=(-(T319*y(2)*T697));
  g1(34,27)=(-(T319*y(3)*T740));
  g1(34,30)=(-(T325*y(41)*1/params(16)));
  g1(34,31)=(-(y(33)*params(12)*params(18)*T822/(1-params(12)*params(18))));
  g1(34,33)=1/(1-params(12)*params(18))-params(12)*params(18)*T328/(1-params(12)*params(18));
  g1(34,41)=(-(y(30)/params(16)*T325));
  g1(35,1)=(-(y(41)*T320));
  g1(35,2)=(-(T242*y(41)));
  g1(35,3)=(-(T292*y(41)));
  g1(35,7)=(-(y(41)*T320));
  g1(35,8)=(-(y(41)*T320));
  g1(35,17)=(-(y(41)*T642));
  g1(35,23)=(-(y(41)*y(2)*T697));
  g1(35,27)=(-(y(41)*y(3)*T740));
  g1(35,31)=(-(y(34)*params(12)*params(18)*T827/(1-params(12)*params(18))));
  g1(35,34)=1/(1-params(12)*params(18))-params(12)*params(18)*T337/(1-params(12)*params(18));
  g1(35,41)=(-T325);
  g1(36,31)=(-(params(18)*T827));
  g1(36,32)=(-((1-params(18))*getPowerDeriv(y(32),1-params(17),1)));
  g1(37,31)=(-(y(35)*params(18)*T822));
  g1(37,32)=(-((1-params(18))*getPowerDeriv(y(32),(-params(17)),1)));
  g1(37,35)=1-params(18)*T328;
  g1(38,1)=(-y(36));
  g1(38,2)=(-y(36));
  g1(38,3)=(-y(36));
  g1(38,7)=(-y(36));
  g1(38,8)=(-y(36));
  g1(38,30)=(-y(43));
  g1(38,36)=(-(y(8)+y(7)+y(3)+y(2)+y(1)));
  g1(38,41)=1;
  g1(38,43)=(-y(30));
  g1(39,2)=(-(exp(x(7))*T382*exp(y(2))*getPowerDeriv(exp(y(2)),params(22),1)));
  g1(39,6)=(-(exp(x(7))*T385*T372*(T378*(-y(41))/(y(6)*y(6))-y(41)/y(6)*(-(y(41)))/((y(6))*(y(6))))/(T378*T378)*T535));
  g1(39,31)=(-(exp(x(7))*T385*T381*((y(31))-y(31))/((y(31))*(y(31)))*getPowerDeriv(y(31)/(y(31)),params(20),1)));
  g1(39,40)=((y(40))-y(40))/((y(40))*(y(40)));
  g1(39,41)=(-(exp(x(7))*T385*T372*T535*(T378*1/y(6)-y(41)/y(6)*1/(y(6)))/(T378*T378)));
  g1(40,1)=y(37);
  g1(40,2)=y(39);
  g1(40,3)=y(38);
  g1(40,7)=y(37);
  g1(40,8)=y(37);
  g1(40,37)=y(8)+y(1)+y(7);
  g1(40,38)=y(3);
  g1(40,39)=y(2);
  g1(41,1)=(-y(17));
  g1(41,2)=(-y(23));
  g1(41,3)=(-y(27));
  g1(41,7)=(-y(17));
  g1(41,8)=(-y(17));
  g1(41,17)=(-(y(8)+y(1)+y(7)));
  g1(41,23)=(-y(2));
  g1(41,27)=(-y(3));
  g1(41,42)=1;
  g1(42,1)=(-y(18));
  g1(42,2)=(-(y(24)*params(14)));
  g1(42,3)=(-y(28));
  g1(42,7)=(-y(18));
  g1(42,8)=(-y(18));
  g1(42,18)=(-(y(8)+y(1)+y(7)));
  g1(42,24)=(-(y(2)*params(14)));
  g1(42,28)=(-y(3));
  g1(42,43)=1;
  g1(43,35)=y(41);
  g1(43,41)=y(35);
  g1(43,43)=(-params(16));
  g1(44,41)=(-1);
  g1(44,42)=1;
  g1(44,44)=1;
  g1(45,1)=(-1);
  g1(45,45)=1;
  g1(46,2)=(-1);
  g1(46,46)=1;
  g1(47,3)=(-1);
  g1(47,47)=1;
  g1(48,7)=(-1);
  g1(48,48)=1;
  g1(49,8)=(-1);
  g1(49,49)=1;
  g1(50,50)=1-params(27);
  g1(51,51)=1-params(28);
  g1(52,52)=1-params(29);
  g1(53,53)=1-params(30);
  g1(54,54)=1-params(31);
  g1(55,55)=1-params(32);
  g1(56,1)=(-(log(y(17))+params(11)*log(1-y(18))));
  g1(56,2)=(-(log(y(23))+params(11)*log(1-y(24))));
  g1(56,3)=(-(log(y(27))+params(11)*log(1-y(28))));
  g1(56,4)=log(y(27))-params(11)*log(1-y(28));
  g1(56,7)=(-(log(y(17))+params(11)*log(1-y(18))));
  g1(56,8)=(-(log(y(17))+params(11)*log(1-y(18))));
  g1(56,17)=(-((y(8)+y(1)+y(7))*1/y(17)));
  g1(56,18)=(-((y(8)+y(1)+y(7))*params(11)*(-1)/(1-y(18))));
  g1(56,23)=(-(y(2)*1/y(23)));
  g1(56,24)=(-(y(2)*params(11)*(-1)/(1-y(24))));
  g1(56,27)=(-(y(3)*1/y(27)-y(4)*1/y(27)));
  g1(56,28)=(-(y(3)*params(11)*(-1)/(1-y(28))-y(4)*(-(params(11)*(-1)/(1-y(28))))));
  g1(56,56)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],56,3136);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],56,175616);
end
end
end
end
