function [residual, g1, g2, g3] = covidmacro_vaccines_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(56, 1);
T100 = (1-y(69))^params(26)*params(3);
T260 = y(42)^(-params(10));
T313 = y(46)^(-params(10));
T341 = y(49)/params(16)*y(60);
T342 = y(36)^(-params(10));
T347 = (y(7)+y(1)+y(6))*T342+y(2)*T260+y(3)*T313;
T351 = params(12)*params(18)*y(82)^params(17);
T361 = params(12)*params(18)*y(82)^(params(17)-1);
T377 = params(18)*y(50)^params(17);
T399 = (y(50)/(steady_state(31)))^params(20);
T405 = (steady_state(41))/(steady_state(6))+x(it_, 9);
T406 = y(60)/y(25)/T405;
T408 = T406^params(21);
T409 = T399*T408;
T412 = exp(y(21))^params(22);
T413 = T409*T412;
T417 = exp(y(21)-y(2))^params(23);
lhs =y(30);
rhs =min(3*params(4),params(4)*(1+y(2)/params(6)));
residual(1)= lhs-rhs;
lhs =y(31);
rhs =0.3888888888888889-y(30);
residual(2)= lhs-rhs;
lhs =y(24);
rhs =y(1)*y(39);
residual(3)= lhs-rhs;
lhs =y(20);
rhs =y(1)-y(24);
residual(4)= lhs-rhs;
lhs =y(21);
rhs =y(2)+y(24)*params(8)-y(2)*(y(30)+y(31));
residual(5)= lhs-rhs;
lhs =y(26);
rhs =y(6)+y(24)*(1-params(8))-(y(30)+y(31))*y(6);
residual(6)= lhs-rhs;
lhs =y(22);
rhs =y(3)+y(2)*y(31)+params(9)*y(7);
residual(7)= lhs-rhs;
lhs =y(27);
rhs =(y(30)+y(31))*y(6)+y(7)*(1-params(9));
residual(8)= lhs-rhs;
lhs =y(23);
rhs =y(4)+y(30)*y(2);
residual(9)= lhs-rhs;
lhs =y(25);
rhs =y(5)-y(30)*y(2);
residual(10)= lhs-rhs;
lhs =y(39);
rhs =params(1)*y(36)*(y(2)*params(13)*y(42)+y(36)*y(6)*params(7))+params(2)*y(37)*(y(2)*params(15)*y(43)+y(6)*params(7)*y(37))+T100*(y(2)+y(6)*params(7));
residual(11)= lhs-rhs;
lhs =y(29);
rhs =((1-params(9))*y(9)+(y(30)+y(31))*y(8))/(1-y(39));
residual(12)= lhs-rhs;
lhs =y(28);
rhs =y(8)*(1-y(31)-y(30))/(1-y(39))+y(39)*(1-params(8))/(1-y(39));
residual(13)= lhs-rhs;
lhs =y(32);
rhs =1-y(33)-y(34);
residual(14)= lhs-rhs;
lhs =y(33);
rhs =y(39)*params(8)/(y(9)+1+y(8));
residual(15)= lhs-rhs;
lhs =y(34);
rhs =params(9)*y(9)/(y(9)+1+y(8));
residual(16)= lhs-rhs;
lhs =y(35);
rhs =log(y(36))+params(11)*log(1-y(37))+params(12)*((1-y(33)-y(34))*y(76)+y(33)*y(78)+y(34)*y(80));
residual(17)= lhs-rhs;
lhs =(y(7)+y(1)+y(6))*(y(36)+y(56)-y(37)*y(49)-y(55));
rhs =y(11)*(y(15)-params(8)*(y(15)-y(1))+y(18)+(1-params(9))*y(19))*y(14)/y(50);
residual(18)= lhs-rhs;
lhs =y(36)^(-1);
rhs =(1+y(69))*y(38)-(y(2)*params(13)*y(42)+y(36)*y(6)*params(7))*params(1)*y(40);
residual(19)= lhs-rhs;
lhs =params(8)*params(12)*(y(78)-y(76));
rhs =(y(9)+1+y(8))*y(40);
residual(20)= lhs-rhs;
lhs =params(11)/(1-y(37));
rhs =y(38)*y(49)*(1-y(72))+(y(2)*params(15)*y(43)+y(6)*params(7)*y(37))*params(2)*y(40);
residual(21)= lhs-rhs;
lhs =y(38);
rhs =(1-y(33)-y(34))*params(12)*y(77)*y(59)/y(82)+y(59)*y(33)*params(12)*y(79)/y(82)+y(59)*y(34)*params(12)*y(81)/y(82);
residual(22)= lhs-rhs;
lhs =y(41);
rhs =log(y(42))+params(11)*log(1-y(43))+params(12)*((1-y(31)-y(30))*y(78)+y(31)*y(80)+y(30)*params(19));
residual(23)= lhs-rhs;
lhs =y(2)*(y(42)+y(58)-y(43)*y(49)*params(14)-y(55));
rhs =y(14)*((1-y(31))*y(13)*y(16)+(y(15)-y(1))*params(8)*y(11))/y(50);
residual(24)= lhs-rhs;
lhs =T260;
rhs =(1+y(70))*y(44);
residual(25)= lhs-rhs;
lhs =y(43);
rhs =max(1-params(11)/(y(49)*params(14)*y(44)),0);
residual(26)= lhs-rhs;
lhs =y(44);
rhs =y(59)*y(79)*(1-y(31)-y(30))*params(12)/y(82)/(1-y(30))+y(59)*y(81)*y(31)*params(12)/y(82)/(1-y(30));
residual(27)= lhs-rhs;
lhs =y(45);
rhs =log(y(46))+params(11)*log(1-y(47))+params(12)*y(80);
residual(28)= lhs-rhs;
lhs =y(3)*(y(46)+y(57)-y(49)*y(47)-y(55));
rhs =y(14)*(y(12)*y(17)+y(16)*y(31)*y(13)+y(19)*params(9)*y(11))/y(50);
residual(29)= lhs-rhs;
lhs =T313;
rhs =(1+y(71))*y(48);
residual(30)= lhs-rhs;
lhs =params(11)/(1-y(47));
rhs =y(48)*y(49)*(1-y(74));
residual(31)= lhs-rhs;
lhs =y(48);
rhs =y(59)*params(12)*y(81)/y(82);
residual(32)= lhs-rhs;
lhs =y(51);
rhs =y(52)/y(53);
residual(33)= lhs-rhs;
lhs =y(52)/(1-params(12)*params(18));
rhs =T341*T347+T351*y(83)/(1-params(12)*params(18));
residual(34)= lhs-rhs;
lhs =y(53)/(1-params(12)*params(18));
rhs =y(60)*T347+T361*y(84)/(1-params(12)*params(18));
residual(35)= lhs-rhs;
lhs =1;
rhs =params(18)*y(50)^(params(17)-1)+(1-params(18))*y(51)^(1-params(17));
residual(36)= lhs-rhs;
lhs =y(54);
rhs =T377*y(10)+(1-params(18))*y(51)^(-params(17));
residual(37)= lhs-rhs;
lhs =y(60)-y(49)*y(62);
rhs =y(55)*(y(7)+y(6)+y(3)+y(2)+y(1));
residual(38)= lhs-rhs;
lhs =y(59)/(steady_state(40));
rhs =T413*T417*exp(x(it_, 8));
residual(39)= lhs-rhs;
residual(40) = (y(7)+y(1)+y(6))*y(56)+y(3)*y(57)+y(2)*y(58);
lhs =y(61);
rhs =y(36)*(y(7)+y(1)+y(6))+y(2)*y(42)+y(3)*y(46);
residual(41)= lhs-rhs;
lhs =y(62);
rhs =y(37)*(y(7)+y(1)+y(6))+params(14)*y(2)*y(43)+y(3)*y(47);
residual(42)= lhs-rhs;
lhs =y(60)*y(54);
rhs =params(16)*y(62);
residual(43)= lhs-rhs;
lhs =y(63);
rhs =y(60)-y(61);
residual(44)= lhs-rhs;
lhs =y(64);
rhs =y(1);
residual(45)= lhs-rhs;
lhs =y(65);
rhs =y(2);
residual(46)= lhs-rhs;
lhs =y(66);
rhs =y(3);
residual(47)= lhs-rhs;
lhs =y(67);
rhs =y(6);
residual(48)= lhs-rhs;
lhs =y(68);
rhs =y(7);
residual(49)= lhs-rhs;
lhs =y(69);
rhs =y(2)*params(24);
residual(50)= lhs-rhs;
lhs =y(72);
rhs =y(2)*params(25);
residual(51)= lhs-rhs;
lhs =y(70);
rhs =y(69);
residual(52)= lhs-rhs;
lhs =y(71);
rhs =y(69);
residual(53)= lhs-rhs;
lhs =y(73);
rhs =y(72);
residual(54)= lhs-rhs;
lhs =y(74);
rhs =y(72);
residual(55)= lhs-rhs;
lhs =y(75);
rhs =(log(y(36))+params(11)*log(1-y(37)))*(y(7)+y(1)+y(6))+y(2)*(log(y(42))+params(11)*log(1-y(43)))+y(3)*(log(y(46))+params(11)*log(1-y(47)))-y(4)*(log(y(46))-params(11)*log(1-y(47)));
residual(56)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(56, 94);

  %
  % Jacobian matrix
  %

T523 = getPowerDeriv(exp(y(21)-y(2)),params(23),1);
T556 = getPowerDeriv(T406,params(21),1);
T664 = (y(7)+y(1)+y(6))*getPowerDeriv(y(36),(-params(10)),1);
T719 = getPowerDeriv(y(42),(-params(10)),1);
T761 = getPowerDeriv(y(46),(-params(10)),1);
  g1(1,2)=(-(params(4)*1/params(6)*(1-(params(4)*(1+y(2)/params(6))>3*params(4)))));
  g1(1,30)=1;
  g1(2,30)=1;
  g1(2,31)=1;
  g1(3,1)=(-y(39));
  g1(3,24)=1;
  g1(3,39)=(-y(1));
  g1(4,1)=(-1);
  g1(4,20)=1;
  g1(4,24)=1;
  g1(5,2)=(-(1-(y(30)+y(31))));
  g1(5,21)=1;
  g1(5,24)=(-params(8));
  g1(5,30)=y(2);
  g1(5,31)=y(2);
  g1(6,24)=(-(1-params(8)));
  g1(6,6)=(-(1-(y(30)+y(31))));
  g1(6,26)=1;
  g1(6,30)=y(6);
  g1(6,31)=y(6);
  g1(7,2)=(-y(31));
  g1(7,3)=(-1);
  g1(7,22)=1;
  g1(7,7)=(-params(9));
  g1(7,31)=(-y(2));
  g1(8,6)=(-(y(30)+y(31)));
  g1(8,7)=(-(1-params(9)));
  g1(8,27)=1;
  g1(8,30)=(-y(6));
  g1(8,31)=(-y(6));
  g1(9,2)=(-y(30));
  g1(9,4)=(-1);
  g1(9,23)=1;
  g1(9,30)=(-y(2));
  g1(10,2)=y(30);
  g1(10,5)=(-1);
  g1(10,25)=1;
  g1(10,30)=y(2);
  g1(11,2)=(-(T100+params(1)*y(36)*params(13)*y(42)+params(2)*y(37)*params(15)*y(43)));
  g1(11,6)=(-(params(1)*y(36)*y(36)*params(7)+params(2)*y(37)*params(7)*y(37)+params(7)*T100));
  g1(11,36)=(-(params(1)*(y(2)*params(13)*y(42)+y(36)*y(6)*params(7))+params(1)*y(36)*y(6)*params(7)));
  g1(11,37)=(-(params(2)*(y(2)*params(15)*y(43)+y(6)*params(7)*y(37))+y(6)*params(7)*params(2)*y(37)));
  g1(11,39)=1;
  g1(11,42)=(-(params(1)*y(36)*y(2)*params(13)));
  g1(11,43)=(-(params(2)*y(37)*y(2)*params(15)));
  g1(11,69)=(-((y(2)+y(6)*params(7))*params(3)*(-(getPowerDeriv(1-y(69),params(26),1)))));
  g1(12,8)=(-((y(30)+y(31))/(1-y(39))));
  g1(12,9)=(-((1-params(9))/(1-y(39))));
  g1(12,29)=1;
  g1(12,30)=(-(y(8)/(1-y(39))));
  g1(12,31)=(-(y(8)/(1-y(39))));
  g1(12,39)=(-(((1-params(9))*y(9)+(y(30)+y(31))*y(8))/((1-y(39))*(1-y(39)))));
  g1(13,8)=(-((1-y(31)-y(30))/(1-y(39))));
  g1(13,28)=1;
  g1(13,30)=(-((-y(8))/(1-y(39))));
  g1(13,31)=(-((-y(8))/(1-y(39))));
  g1(13,39)=(-(y(8)*(1-y(31)-y(30))/((1-y(39))*(1-y(39)))+((1-params(8))*(1-y(39))-(-(y(39)*(1-params(8)))))/((1-y(39))*(1-y(39)))));
  g1(14,32)=1;
  g1(14,33)=1;
  g1(14,34)=1;
  g1(15,8)=(-((-(y(39)*params(8)))/((y(9)+1+y(8))*(y(9)+1+y(8)))));
  g1(15,9)=(-((-(y(39)*params(8)))/((y(9)+1+y(8))*(y(9)+1+y(8)))));
  g1(15,33)=1;
  g1(15,39)=(-(params(8)/(y(9)+1+y(8))));
  g1(16,8)=(-((-(params(9)*y(9)))/((y(9)+1+y(8))*(y(9)+1+y(8)))));
  g1(16,9)=(-((params(9)*(y(9)+1+y(8))-params(9)*y(9))/((y(9)+1+y(8))*(y(9)+1+y(8)))));
  g1(16,34)=1;
  g1(17,33)=(-(params(12)*(y(78)+(-y(76)))));
  g1(17,34)=(-(params(12)*(y(80)+(-y(76)))));
  g1(17,35)=1;
  g1(17,76)=(-((1-y(33)-y(34))*params(12)));
  g1(17,36)=(-(1/y(36)));
  g1(17,37)=(-(params(11)*(-1)/(1-y(37))));
  g1(17,78)=(-(y(33)*params(12)));
  g1(17,80)=(-(y(34)*params(12)));
  g1(18,1)=y(36)+y(56)-y(37)*y(49)-y(55)-y(14)*params(8)*y(11)/y(50);
  g1(18,6)=y(36)+y(56)-y(37)*y(49)-y(55);
  g1(18,7)=y(36)+y(56)-y(37)*y(49)-y(55);
  g1(18,36)=y(7)+y(1)+y(6);
  g1(18,37)=(y(7)+y(1)+y(6))*(-y(49));
  g1(18,49)=(y(7)+y(1)+y(6))*(-y(37));
  g1(18,50)=(-((-(y(11)*(y(15)-params(8)*(y(15)-y(1))+y(18)+(1-params(9))*y(19))*y(14)))/(y(50)*y(50))));
  g1(18,55)=(-(y(7)+y(1)+y(6)));
  g1(18,11)=(-((y(15)-params(8)*(y(15)-y(1))+y(18)+(1-params(9))*y(19))*y(14)/y(50)));
  g1(18,56)=y(7)+y(1)+y(6);
  g1(18,14)=(-(y(11)*(y(15)-params(8)*(y(15)-y(1))+y(18)+(1-params(9))*y(19))/y(50)));
  g1(18,15)=(-(y(14)*(1-params(8))*y(11)/y(50)));
  g1(18,18)=(-(y(11)*y(14)/y(50)));
  g1(18,19)=(-(y(14)*(1-params(9))*y(11)/y(50)));
  g1(19,2)=params(1)*y(40)*params(13)*y(42);
  g1(19,6)=params(1)*y(40)*y(36)*params(7);
  g1(19,36)=getPowerDeriv(y(36),(-1),1)-(-(y(6)*params(7)*params(1)*y(40)));
  g1(19,38)=(-(1+y(69)));
  g1(19,40)=params(1)*(y(2)*params(13)*y(42)+y(36)*y(6)*params(7));
  g1(19,42)=y(2)*params(13)*params(1)*y(40);
  g1(19,69)=(-y(38));
  g1(20,8)=(-y(40));
  g1(20,9)=(-y(40));
  g1(20,76)=(-(params(8)*params(12)));
  g1(20,40)=(-(y(9)+1+y(8)));
  g1(20,78)=params(8)*params(12);
  g1(21,2)=(-(params(2)*y(40)*params(15)*y(43)));
  g1(21,6)=(-(params(2)*y(40)*params(7)*y(37)));
  g1(21,37)=params(11)/((1-y(37))*(1-y(37)))-y(6)*params(7)*params(2)*y(40);
  g1(21,38)=(-(y(49)*(1-y(72))));
  g1(21,40)=(-(params(2)*(y(2)*params(15)*y(43)+y(6)*params(7)*y(37))));
  g1(21,43)=(-(y(2)*params(15)*params(2)*y(40)));
  g1(21,49)=(-(y(38)*(1-y(72))));
  g1(21,72)=(-(y(38)*(-y(49))));
  g1(22,33)=(-(y(59)*y(77)*(-params(12))/y(82)+y(59)*params(12)*y(79)/y(82)));
  g1(22,34)=(-(y(59)*params(12)*y(81)/y(82)+y(59)*y(77)*(-params(12))/y(82)));
  g1(22,38)=1;
  g1(22,77)=(-((1-y(33)-y(34))*params(12)*y(59)/y(82)));
  g1(22,79)=(-(y(59)*y(33)*params(12)/y(82)));
  g1(22,81)=(-(y(59)*y(34)*params(12)/y(82)));
  g1(22,82)=(-((-((1-y(33)-y(34))*params(12)*y(77)*y(59)))/(y(82)*y(82))+(-(y(59)*y(33)*params(12)*y(79)))/(y(82)*y(82))+(-(y(59)*y(34)*params(12)*y(81)))/(y(82)*y(82))));
  g1(22,59)=(-((1-y(33)-y(34))*params(12)*y(77)/y(82)+y(33)*params(12)*y(79)/y(82)+y(34)*params(12)*y(81)/y(82)));
  g1(23,30)=(-(params(12)*(params(19)+(-y(78)))));
  g1(23,31)=(-(params(12)*(y(80)+(-y(78)))));
  g1(23,41)=1;
  g1(23,78)=(-((1-y(31)-y(30))*params(12)));
  g1(23,42)=(-(1/y(42)));
  g1(23,43)=(-(params(11)*(-1)/(1-y(43))));
  g1(23,80)=(-(y(31)*params(12)));
  g1(24,1)=(-(y(14)*(-(params(8)*y(11)))/y(50)));
  g1(24,2)=y(42)+y(58)-y(43)*y(49)*params(14)-y(55);
  g1(24,31)=(-(y(14)*(-(y(13)*y(16)))/y(50)));
  g1(24,42)=y(2);
  g1(24,43)=y(2)*(-(y(49)*params(14)));
  g1(24,49)=y(2)*(-(y(43)*params(14)));
  g1(24,50)=(-((-(y(14)*((1-y(31))*y(13)*y(16)+(y(15)-y(1))*params(8)*y(11))))/(y(50)*y(50))));
  g1(24,55)=(-y(2));
  g1(24,11)=(-(params(8)*(y(15)-y(1))*y(14)/y(50)));
  g1(24,13)=(-(y(14)*(1-y(31))*y(16)/y(50)));
  g1(24,58)=y(2);
  g1(24,14)=(-(((1-y(31))*y(13)*y(16)+(y(15)-y(1))*params(8)*y(11))/y(50)));
  g1(24,15)=(-(y(14)*params(8)*y(11)/y(50)));
  g1(24,16)=(-(y(14)*(1-y(31))*y(13)/y(50)));
  g1(25,42)=T719;
  g1(25,44)=(-(1+y(70)));
  g1(25,70)=(-y(44));
  g1(26,43)=1;
  g1(26,44)=(-((-((-(params(11)*y(49)*params(14)))/(y(49)*params(14)*y(44)*y(49)*params(14)*y(44))))*(1-params(11)/(y(49)*params(14)*y(44))>0)));
  g1(26,49)=(-((1-params(11)/(y(49)*params(14)*y(44))>0)*(-((-(params(11)*params(14)*y(44)))/(y(49)*params(14)*y(44)*y(49)*params(14)*y(44))))));
  g1(27,30)=(-(((1-y(30))*y(59)*y(79)*(-params(12))/y(82)-(-(y(59)*y(79)*(1-y(31)-y(30))*params(12)/y(82))))/((1-y(30))*(1-y(30)))+y(59)*y(81)*y(31)*params(12)/y(82)/((1-y(30))*(1-y(30)))));
  g1(27,31)=(-(y(59)*y(79)*(-params(12))/y(82)/(1-y(30))+y(59)*params(12)*y(81)/y(82)/(1-y(30))));
  g1(27,44)=1;
  g1(27,79)=(-(y(59)*(1-y(31)-y(30))*params(12)/y(82)/(1-y(30))));
  g1(27,81)=(-(y(59)*y(31)*params(12)/y(82)/(1-y(30))));
  g1(27,82)=(-((-(y(59)*y(79)*(1-y(31)-y(30))*params(12)))/(y(82)*y(82))/(1-y(30))+(-(y(59)*y(81)*y(31)*params(12)))/(y(82)*y(82))/(1-y(30))));
  g1(27,59)=(-(y(79)*(1-y(31)-y(30))*params(12)/y(82)/(1-y(30))+y(81)*y(31)*params(12)/y(82)/(1-y(30))));
  g1(28,45)=1;
  g1(28,80)=(-params(12));
  g1(28,46)=(-(1/y(46)));
  g1(28,47)=(-(params(11)*(-1)/(1-y(47))));
  g1(29,3)=y(46)+y(57)-y(49)*y(47)-y(55);
  g1(29,31)=(-(y(14)*y(13)*y(16)/y(50)));
  g1(29,46)=y(3);
  g1(29,47)=y(3)*(-y(49));
  g1(29,49)=y(3)*(-y(47));
  g1(29,50)=(-((-(y(14)*(y(12)*y(17)+y(16)*y(31)*y(13)+y(19)*params(9)*y(11))))/(y(50)*y(50))));
  g1(29,55)=(-y(3));
  g1(29,11)=(-(y(14)*params(9)*y(19)/y(50)));
  g1(29,12)=(-(y(14)*y(17)/y(50)));
  g1(29,57)=y(3);
  g1(29,13)=(-(y(14)*y(31)*y(16)/y(50)));
  g1(29,14)=(-((y(12)*y(17)+y(16)*y(31)*y(13)+y(19)*params(9)*y(11))/y(50)));
  g1(29,16)=(-(y(14)*y(31)*y(13)/y(50)));
  g1(29,17)=(-(y(14)*y(12)/y(50)));
  g1(29,19)=(-(y(14)*params(9)*y(11)/y(50)));
  g1(30,46)=T761;
  g1(30,48)=(-(1+y(71)));
  g1(30,71)=(-y(48));
  g1(31,47)=params(11)/((1-y(47))*(1-y(47)));
  g1(31,48)=(-(y(49)*(1-y(74))));
  g1(31,49)=(-(y(48)*(1-y(74))));
  g1(31,74)=(-(y(48)*(-y(49))));
  g1(32,48)=1;
  g1(32,81)=(-(params(12)*y(59)/y(82)));
  g1(32,82)=(-((-(y(59)*params(12)*y(81)))/(y(82)*y(82))));
  g1(32,59)=(-(params(12)*y(81)/y(82)));
  g1(33,51)=1;
  g1(33,52)=(-(1/y(53)));
  g1(33,53)=(-((-y(52))/(y(53)*y(53))));
  g1(34,1)=(-(T341*T342));
  g1(34,2)=(-(T260*T341));
  g1(34,3)=(-(T313*T341));
  g1(34,6)=(-(T341*T342));
  g1(34,7)=(-(T341*T342));
  g1(34,36)=(-(T341*T664));
  g1(34,42)=(-(T341*y(2)*T719));
  g1(34,46)=(-(T341*y(3)*T761));
  g1(34,49)=(-(T347*y(60)*1/params(16)));
  g1(34,82)=(-(y(83)*params(12)*params(18)*getPowerDeriv(y(82),params(17),1)/(1-params(12)*params(18))));
  g1(34,52)=1/(1-params(12)*params(18));
  g1(34,83)=(-(T351/(1-params(12)*params(18))));
  g1(34,60)=(-(y(49)/params(16)*T347));
  g1(35,1)=(-(y(60)*T342));
  g1(35,2)=(-(T260*y(60)));
  g1(35,3)=(-(T313*y(60)));
  g1(35,6)=(-(y(60)*T342));
  g1(35,7)=(-(y(60)*T342));
  g1(35,36)=(-(y(60)*T664));
  g1(35,42)=(-(y(60)*y(2)*T719));
  g1(35,46)=(-(y(60)*y(3)*T761));
  g1(35,82)=(-(y(84)*params(12)*params(18)*getPowerDeriv(y(82),params(17)-1,1)/(1-params(12)*params(18))));
  g1(35,53)=1/(1-params(12)*params(18));
  g1(35,84)=(-(T361/(1-params(12)*params(18))));
  g1(35,60)=(-T347);
  g1(36,50)=(-(params(18)*getPowerDeriv(y(50),params(17)-1,1)));
  g1(36,51)=(-((1-params(18))*getPowerDeriv(y(51),1-params(17),1)));
  g1(37,50)=(-(y(10)*params(18)*getPowerDeriv(y(50),params(17),1)));
  g1(37,51)=(-((1-params(18))*getPowerDeriv(y(51),(-params(17)),1)));
  g1(37,10)=(-T377);
  g1(37,54)=1;
  g1(38,1)=(-y(55));
  g1(38,2)=(-y(55));
  g1(38,3)=(-y(55));
  g1(38,6)=(-y(55));
  g1(38,7)=(-y(55));
  g1(38,49)=(-y(62));
  g1(38,55)=(-(y(7)+y(6)+y(3)+y(2)+y(1)));
  g1(38,60)=1;
  g1(38,62)=(-y(49));
  g1(39,2)=(-(exp(x(it_, 8))*T413*(-exp(y(21)-y(2)))*T523));
  g1(39,21)=(-(exp(x(it_, 8))*(T417*T409*exp(y(21))*getPowerDeriv(exp(y(21)),params(22),1)+T413*exp(y(21)-y(2))*T523)));
  g1(39,25)=(-(exp(x(it_, 8))*T417*T412*T399*(-y(60))/(y(25)*y(25))/T405*T556));
  g1(39,50)=(-(exp(x(it_, 8))*T417*T412*T408*1/(steady_state(31))*getPowerDeriv(y(50)/(steady_state(31)),params(20),1)));
  g1(39,59)=1/(steady_state(40));
  g1(39,60)=(-(exp(x(it_, 8))*T417*T412*T399*T556*1/y(25)/T405));
  g1(39,92)=(-(T413*T417*exp(x(it_, 8))));
  g1(39,93)=(-(exp(x(it_, 8))*T417*T412*T399*T556*(-(y(60)/y(25)))/(T405*T405)));
  g1(40,1)=y(56);
  g1(40,2)=y(58);
  g1(40,3)=y(57);
  g1(40,6)=y(56);
  g1(40,7)=y(56);
  g1(40,56)=y(7)+y(1)+y(6);
  g1(40,57)=y(3);
  g1(40,58)=y(2);
  g1(41,1)=(-y(36));
  g1(41,2)=(-y(42));
  g1(41,3)=(-y(46));
  g1(41,6)=(-y(36));
  g1(41,7)=(-y(36));
  g1(41,36)=(-(y(7)+y(1)+y(6)));
  g1(41,42)=(-y(2));
  g1(41,46)=(-y(3));
  g1(41,61)=1;
  g1(42,1)=(-y(37));
  g1(42,2)=(-(y(43)*params(14)));
  g1(42,3)=(-y(47));
  g1(42,6)=(-y(37));
  g1(42,7)=(-y(37));
  g1(42,37)=(-(y(7)+y(1)+y(6)));
  g1(42,43)=(-(y(2)*params(14)));
  g1(42,47)=(-y(3));
  g1(42,62)=1;
  g1(43,54)=y(60);
  g1(43,60)=y(54);
  g1(43,62)=(-params(16));
  g1(44,60)=(-1);
  g1(44,61)=1;
  g1(44,63)=1;
  g1(45,1)=(-1);
  g1(45,64)=1;
  g1(46,2)=(-1);
  g1(46,65)=1;
  g1(47,3)=(-1);
  g1(47,66)=1;
  g1(48,6)=(-1);
  g1(48,67)=1;
  g1(49,7)=(-1);
  g1(49,68)=1;
  g1(50,2)=(-params(24));
  g1(50,69)=1;
  g1(51,2)=(-params(25));
  g1(51,72)=1;
  g1(52,69)=(-1);
  g1(52,70)=1;
  g1(53,69)=(-1);
  g1(53,71)=1;
  g1(54,72)=(-1);
  g1(54,73)=1;
  g1(55,72)=(-1);
  g1(55,74)=1;
  g1(56,1)=(-(log(y(36))+params(11)*log(1-y(37))));
  g1(56,2)=(-(log(y(42))+params(11)*log(1-y(43))));
  g1(56,3)=(-(log(y(46))+params(11)*log(1-y(47))));
  g1(56,4)=log(y(46))-params(11)*log(1-y(47));
  g1(56,6)=(-(log(y(36))+params(11)*log(1-y(37))));
  g1(56,7)=(-(log(y(36))+params(11)*log(1-y(37))));
  g1(56,36)=(-((y(7)+y(1)+y(6))*1/y(36)));
  g1(56,37)=(-((y(7)+y(1)+y(6))*params(11)*(-1)/(1-y(37))));
  g1(56,42)=(-(y(2)*1/y(42)));
  g1(56,43)=(-(y(2)*params(11)*(-1)/(1-y(43))));
  g1(56,46)=(-(y(3)*1/y(46)-y(4)*1/y(46)));
  g1(56,47)=(-(y(3)*params(11)*(-1)/(1-y(47))-y(4)*(-(params(11)*(-1)/(1-y(47))))));
  g1(56,75)=1;

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],56,8836);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],56,830584);
end
end
end
end
